Eliater |release| Documentation
===============================

.. todolist::

Table of Contents
-----------------
.. toctree::
   :maxdepth: 2
   :caption: Getting Started
   :name: start

   installation
   usage
   examples


Indices and Tables
------------------
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
